@@ -1,8 +1,6 @@
 from django.conf.urls import include, url
 from django.contrib import admin
-
-admin.autodiscover()
-
+from django.contrib.staticfiles import views
 
 urlpatterns = [
     # Uncomment the next line to enable the admin:
@@ -12,6 +10,6 @@ urlpatterns = [
 
     url(r'', include('django_restframework_gis_tests.urls')),
 
-    url(r'^static/(?P<path>.*)$', 'django.contrib.staticfiles.views.serve'),
+    url(r'^static/(?P<path>.*)$', views.serve),
 
 ]
